/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/
 
package org.apache.muse.core.descriptor;

import org.w3c.dom.Element;

import org.apache.muse.core.Environment;
import org.apache.muse.core.routing.RouterPersistence;
import org.apache.muse.util.messages.Messages;
import org.apache.muse.util.messages.MessagesFactory;
import org.apache.muse.ws.addressing.soap.SoapFault;

/**
 * 
 * @author Dan Jemiolo (danj)
 *
 */

public class RouterPersistenceDescriptor extends SimplePersistenceDescriptor
{
    //
    // Used to lookup all exception messages
    //
    private static Messages _MESSAGES = 
        MessagesFactory.get(RouterPersistenceDescriptor.class);
        
    public void load(Element persistenceXML, Environment env) 
        throws SoapFault
    {
        super.load(persistenceXML, env);
        
        //
        // make sure this class is an instance of RouterPersistence, not 
        // just regular Persistence
        //
        Class theClass = getPersistenceDefinition().getPersistenceClass();
        
        if (!RouterPersistence.class.isAssignableFrom(theClass))
        {
            Object[] filler = { theClass.getName(), RouterPersistence.class.getName() };
            String message = _MESSAGES.get("IncorrectPersistenceRoot", filler);
            throw new RuntimeException(message);
        }
    }
}
