/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/


package org.apache.muse.core.platform.osgi;

import org.osgi.framework.Bundle;


/**
 * ResourceManagementProvider is an interface for Muse application deployment functionality.
 * Use this interface to register ResourceManagementProvider services with the OSGi 
 * runtime using the <code>BundleContext.registerService()</code> methods.
 *
 * Implementers of this interface are responsible for deploying Muse management contexts to
 * their collaborating SOA environments. For example, the Muse Axis2 OSGi platform registers
 * a <code>ResourceManagementAdminService</code> implementation under this interface.
 * 
 * @author Joel Hawkins (joelh)
 *
 */

public interface ResourceManagementProvider {
	
	/**
	 * deploys a Management Endpoint (corresponding a resource type from a muse.xml file) into
	 * the specified context
	 *  
	 * @param contextName
	 * @param homeName
	 * @throws Exception
	 */
	public void deployManagementService(Bundle bundle, String contextName, String homeName, String wsdlPath) throws Exception;

	/**
	 * deploys a Management Endpoint (corresponding a resource type from a muse.xml file) into
	 * the implementation's default context
	 * 
	 * @param homeName
	 * @throws Exception
	 */
	public void deployManagementService(Bundle bundle, String homeName, String wsdlPath) throws Exception;

}
