/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/


package org.apache.muse.core.platform.osgi.descriptor;

import org.apache.muse.core.Capability;
import org.apache.muse.core.Environment;
import org.apache.muse.core.descriptor.DescriptorConstants;
import org.apache.muse.core.descriptor.SimpleCapabilityDescriptor;
import org.apache.muse.core.descriptor.SimpleRouterDescriptor;
import org.apache.muse.util.ReflectUtils;
import org.apache.muse.util.messages.Messages;
import org.apache.muse.util.messages.MessagesFactory;
import org.apache.muse.util.xml.XmlUtils;
import org.w3c.dom.Element;

import org.osgi.framework.Bundle;

/**
 *
 * OSGiCapabilityDescriptor an OSGi-specific extention of SimpleCapabilityDescriptor
 *
 * @see SimpleCapabilityDescriptor
 * @author Joel Hawkins (joelh)
 *
 */

public class OSGiCapabilityDescriptor extends SimpleCapabilityDescriptor {

	private static Messages _MESSAGES = MessagesFactory
			.get(SimpleRouterDescriptor.class);

	private Bundle bundle;

	/**
	 * constructor 
	 * @param bundle the Bundle the capability description was loaded from.
	 */
	public OSGiCapabilityDescriptor(Bundle bundle) {
		super();
		this.bundle = bundle;
	}

	/**
	 * resolves the Class that implements the specified Capability
	 * @param xml the current xml Element corresponding to the capability definition
	 * @param env the Muse environment
	 * @return the <code>Class</code> implementing the capability 
	 */
	protected Class createImplementationClass(Element xml, Environment env) {
		String className = XmlUtils.getElementText(xml,
				DescriptorConstants.JAVA_CAPABILITY_QNAME);
		Class theClass = null;
		ClassLoader loader = env.getClassLoader();
		if (bundle == null) {
			loader = env.getClassLoader();
			theClass = ReflectUtils.getClass(className, loader);
		} else {
			try {
				theClass = ReflectUtils.getClass(className,loader);
				if(theClass == null){
					theClass = bundle.loadClass(className);
				}
			} catch (ClassNotFoundException e) {
				throw new RuntimeException("Class Not Found " + className);
			}
		}

		//
		// make sure this class implements Capability
		//
		if (!Capability.class.isAssignableFrom(theClass)) {
			Object[] filler = { className, Capability.class.getName() };
			String message = _MESSAGES.get("IncorrectCapabilityRoot", filler);
			throw new RuntimeException(message);
		}

		return theClass;
	}

}
