/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.core.platform.osgi.routing;

import java.util.HashMap;

import javax.xml.namespace.QName;

import org.apache.muse.core.platform.osgi.util.OSGiReflectUtilHelper;
import org.apache.muse.core.routing.ResourceIdFactory;
import org.apache.muse.ws.addressing.WsaConstants;
import org.osgi.framework.Bundle;

/**
 *
 * OSGiResourceIdFactory is a simple ID factory that tracks ID values by Bundle
 * 
 * @see ResourceIdFactory
 *
 * @author Joel Hawkins (joelh)
 *
 */

public class OSGiResourceIdFactory implements ResourceIdFactory {

	protected HashMap bundleToCounterMap = new HashMap();
	protected String name;
    private static final String _DEFAULT_NAME = "MuseResource";
    private int count = 0;
    private Integer FIRST = new Integer(1);

	public OSGiResourceIdFactory(){
		name = _DEFAULT_NAME;
	}

    public OSGiResourceIdFactory(String name)
    {
        this.name = name;
    }

    /**
     * returns the QName for the ID factory's identifiers
     * @return the factory's resource id QName
     */
    public QName getIdentifierName() {
        return WsaConstants.DEFAULT_RESOURCE_ID_QNAME;
	}

    /**
     * returns the next identifier as a string. This method uses the thread local Bundle from 
     * the <code>OSGiReflectUtilHelper</class> as the key to find the next counter to increment
     * if there is no active bundle, then a global counter is used
     * 
     * @return the next identifier for the current thread's Bundle
     * @see OSGiReflectUtilHelper#getThreadLocalBundle()
     */
	public synchronized String getNextIdentifier() {
		Bundle bundle = OSGiReflectUtilHelper.getDefault().getThreadLocalBundle();
		if(bundle != null){
			Integer bCount = (Integer)bundleToCounterMap.get(bundle);
			if(bCount == null) bCount = FIRST;
			int value = bCount.intValue();
			bundleToCounterMap.put(bundle, new Integer(value+1));
			return name + '-' + value++;

		} else {
			return name + '-' + count++;
		}
	}

}
