/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/


package org.apache.muse.core.platform.osgi.axis2;

import org.apache.muse.core.platform.osgi.ResourceManagementProvider;

/**
 *
 * ResourceManagementProviderFactory is ...
 *
 * @author Joel Hawkins (joelh)
 *
 */

public class ResourceManagementProviderFactory {
	private ResourceManagementProvider provider;

	private static ResourceManagementProviderFactory sThis;

	private ResourceManagementProviderFactory() {
		sThis = this;
	}

	/**
	 * Get the singleton instance of the ResourceManagementProviderFactory
	 *
	 * @return ResourceManagementProviderFactory object
	 */
	public static ResourceManagementProviderFactory getInstance() {
		if (sThis == null) {
			new ResourceManagementProviderFactory();
		}
		return sThis;
	}

	/**
	 * Register the ResourceManagementProvider the this environment.
	 *
	 * @param provider
	 */
	public void registerManagementProvider(ResourceManagementProvider provider) {
		this.provider = provider;
	}

	/**
	 * Get the service deployer for this environment
	 *
	 * @return The registered service deployer
	 */
	public ResourceManagementProvider getManagementProvider() {
		if (provider == null) {
			throw new IllegalStateException(
					"ResourceManagementProvider has not been registered");
		}

		return provider;
	}
}
