package org.apache.muse.core.platform.osgi.mini.internal;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;

import javax.servlet.ServletContext;
import javax.servlet.http.HttpServletRequest;

import org.apache.muse.core.platform.mini.MiniEnvironment;
import org.apache.muse.core.platform.osgi.OSGiEnvironment;
import org.apache.muse.core.platform.osgi.util.BundleRootHelper;
import org.apache.muse.core.platform.osgi.util.OSGiReflectUtilHelper;
import org.osgi.framework.Bundle;
import org.osgi.framework.BundleContext;

public class OSGiMiniEnvironment extends MiniEnvironment implements OSGiEnvironment {
	
	
	private static BundleContext bundleContext;

	private InheritableThreadLocal localEnvironmentContext = new InheritableThreadLocal();

	
    protected void setRealDirectory(ServletContext servletContext){
    	//TODO see why we need this...
    }
    
	/**
	 * @return A <File> object corresponding to the executing thread's Bundle's 
	 * root directory. This method uses the <code>BundleRootHelper</code> class 
	 * to resolve the root directory.
	 * 
	 * @see BundleRootHelper
	 */
	public File getRealDirectory() {
		Bundle bundle = getThreadLocalBundle();
		if(bundle != null) {
			File root = BundleRootHelper.getRootForBundle(bundle);
			if(root != null) return root;
		}
		return super.getRealDirectory();
	}
    
    
	/**
	 * getter for the Bundle corresponding to the executing thread
	 * @return the current thread's Bundle
	 */
	public Bundle getThreadLocalBundle() {
		return (Bundle) localEnvironmentContext.get();
	}

	/**
	 * setter for the Bundle corresponding to the executing thread
	 * @param bundle the current thread's Bundle
	 */
	public void setThreadLocalBundle(Bundle bundle) {
		localEnvironmentContext.set(bundle);
		OSGiReflectUtilHelper.getDefault().setThreadLocalBundle(bundle);
	}
    

	/**
	 * this method returns an InputStream for a resource based on the 
	 * executing thread's Bundle context.
	 * @param path the path to the resource
	 * @return an <code>InputStream</code> corresponding to the resource if the resource is found,
	 * otherwise <code>null</code>
	 */
	public InputStream getDataResourceStream(String path) {
		if (path == null)
			throw new NullPointerException("NullResourcePath");

		InputStream input = null;
		Bundle bundle = getThreadLocalBundle();
		if (bundle != null) {
			URL url = bundle.getResource(path);
			if (url != null) {
				try {
					input = url.openStream();
				} catch (IOException ioe) {
					input = null;
				}
			}
		}
		
		if (input == null)
			input = this.getClass().getResourceAsStream(path);
		if (input == null)
			input = this.getClass().getResourceAsStream("/OSGI-INF/" + path);
		if (input == null){
			input = OSGiReflectUtilHelper.getDefault().getResource(path);
		}
		if(input == null && bundle != null){
			try {
				File file = BundleRootHelper.getRootForBundle(bundle);
				File lastTry = new File(file.getAbsolutePath() +"/"+ path);
				input = new FileInputStream(lastTry);
			} catch(Throwable t){
				throw new RuntimeException(t.getMessage(), t);
			}
		}
		return input;

	}

    public OSGiMiniEnvironment(HttpServletRequest httpRequest, ServletContext servletContext)
    {
    	super(httpRequest, servletContext);
    }

}
