/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package javax.xml.namespace;

/**
 * 
 * This is an implementation of javax.xml.namespace.QName for J2SE 1.4.x. 
 * This class is available in myriad other places and platforms, but we 
 * need to have one in a consistent place for development time. We could 
 * take one from some other project and declare it The Standard, but that 
 * would make Legal sad.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class QName
{
    private String _localPart = null;
    
    private String _namespaceURI = null;
    
    private String _prefix = null;
    
    public static QName valueOf(String qnameFromToString)
    {
        String namespaceURI = null;
        String localPart = null;
        
        int startLocalPart = 0;
        
        if (qnameFromToString.charAt(0) == '{')
        {
            int closeBracket = qnameFromToString.indexOf('}');
            
            if (closeBracket < 0)
                throw new IllegalArgumentException("Invalid QName string: namespace has no closing bracket.");
            
            if (closeBracket == qnameFromToString.length() - 1)
                throw new IllegalArgumentException("Invalid QName string: no local part after namespace.");
            
            namespaceURI = qnameFromToString.substring(1, closeBracket);
            startLocalPart = closeBracket + 1;
        }
        
        localPart = qnameFromToString.substring(startLocalPart);
        
        return new QName(namespaceURI, localPart, null);
    }
    
    public QName(String localPart)
    {
        this("", localPart, "");
    }
    
    public QName(String namespaceURI, String localPart)
    {
        this(namespaceURI, localPart, "");
    }

    public QName(String namespaceURI, String localPart, String prefix)
    {
        if (namespaceURI == null)
            namespaceURI = "";
        
        if (prefix == null)
            prefix = "";
        
        if (localPart == null || localPart.length() == 0)
            throw new IllegalArgumentException("Invalid QName: null or empty local part.");
        
        _namespaceURI = namespaceURI;
        _localPart = localPart;
        _prefix = prefix;
    }

    public boolean equals(Object obj)
    {
        if (obj == this)
            return true;
        
        QName other = (QName)obj;
        return getNamespaceURI().equals(other.getNamespaceURI()) && 
               getLocalPart().equals(other.getLocalPart());
    }

    public String getLocalPart()
    {
        return _localPart;
    }
    
    public String getNamespaceURI()
    {
        return _namespaceURI;
    }
    
    public String getPrefix()
    {
        return _prefix;
    }
    
    public int hashCode()
    {
        return getNamespaceURI().hashCode() + getLocalPart().hashCode();
    }
    
    public String toString()
    {
        StringBuffer buffer = new StringBuffer();
        String namespaceURI = getNamespaceURI();
        
        if (namespaceURI != null)
        {
            buffer.append('{');
            buffer.append(namespaceURI);
            buffer.append('}');
        }
        
        buffer.append(getLocalPart());
        
        return buffer.toString();
    }
}
