/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.dm.muws;

import java.util.List;

import org.apache.muse.ws.addressing.EndpointReference;
import org.apache.muse.ws.addressing.soap.SoapFault;
import org.apache.muse.ws.resource.WsResource;
import org.apache.muse.util.xml.XmlSerializable;

/**
 *
 * Match represents correlation expressions formatted with the MUWS Simple 
 * Property Boolean Match (PBM) schema. PBM allows the user to declare fairly 
 * complex conditionals for evaluating two resources for equality. The 
 * official PBM Match types are Match, MatchAll, and MatchAny.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public interface Match extends XmlSerializable
{
    /**
     * 
     * @param child
     *        A subexpression that must be evaluated as part of this 
     *        larger expression.
     *
     */
    void addMatch(Match child);
    
    /**
     * 
     * @return An ordered list of subexpressions in this Match. If there are 
     *         no subexpressions, the list is empty.
     *
     */
    List getMatches();

    /**
     * 
     * @return The local resource that is defining the CorrelatableProperties 
     *         capability and, thus, this correlation expression.
     *
     */
    WsResource getWsResource();
    
    /**
     * 
     * @param epr
     *        The EPR to another resource which may be the same as this 
     *        resource.
     * 
     * @return True if the two resources are the same according to the 
     *         conditional test executed by the Match.
     * 
     */
    boolean matches(EndpointReference epr)
        throws SoapFault;
    
    void removeMatch(Match child);
}
