/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.dm.muws.impl;

import javax.xml.namespace.QName;

import org.apache.muse.util.uuid.RandomUuidFactory;
import org.apache.muse.ws.addressing.soap.SoapFault;
import org.apache.muse.ws.dm.muws.Identity;

/**
 *
 * SimpleIdentity is Muse's default implementation of the WSDM Identity capability. 
 * It initializes the muws1:ResourceId property using a random UUID.
 *
 * @author Dan Jemiolo (danj)
 * 
 * @see RandomUuidFactory#createUUID()
 *
 */

public class SimpleIdentity 
    extends AbstractManageabilityCapability implements Identity
{
    private String _resourceID = null;
    
    public QName[] getPropertyNames()
    {
        return PROPERTIES;
    }
        
    public String getResourceId()
    {
       return _resourceID;
    }
    
    public void initialize()
        throws SoapFault
    {
        super.initialize();
        _resourceID = RandomUuidFactory.getInstance().createUUID();
    }
}
