/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.dm.muws.events;

import java.util.Collection;

import javax.xml.namespace.QName;

import org.w3c.dom.Element;

/**
 * 
 * This is a utility interface for WEF components that can be extended 
 * with arbitrary elements (their schema definitions include an xsd:any). 
 * The elements added using this interface's methods will be serialized 
 * under the root element of the concrete class' XML representation.
 * 
 * @author Dan Jemiolo (danj)
 *  
 */

public interface ExtendedElements
{
    /**
     * 
     * @param xml
     *        The custom XML that will be added to end of the WEF component.
     *
     */
    void addExtendedElement(Element xml);
    
    /**
     *
     * @param elementName
     *        The name of the XML element that will be added to the end of 
     *        the WEF component.
     *  
     * @param elementValue
     *        The value that will be serialized to XML and added to the end 
     *        of the WEF component. 
     *
     */
    void addExtendedElement(QName elementName, Object elementValue);
    
    /**
     * 
     * @return All Elements added using the addExtendedElement() method(s).
     *
     */
    Collection getExtendedElements();
    
    /**
     * 
     * @param elementName
     *        The QName of the desired Element(s)
     *        
     * @return The set of extended Elements (which were provided using 
     *         the addExtendedElement() methods) whose names are equal 
     *         to the one given.
     *
     */
    Collection getExtendedElements(QName elementName);
}
