/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.notification;

import java.util.Collection;

import org.apache.muse.core.Capability;

/**
 *
 * NotificationConsumer is an interface that represents the WS-Notification 
 * NotificationConsumer port type; it is based on WS-N 1.3.
 * <br><br>
 * This interface adds a observer-style API to the port type operation (wsnt:Notify) 
 * so that consumers can respond to incoming messages without having to rewrite 
 * the NotificationConsumer implementation code.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public interface NotificationConsumer extends Capability
{
    /**
     * 
     * Adds the listener to the list of listeners that will be notified 
     * whenever a message is received by the resource.
     *
     * @param listener
     *
     */
    void addMessageListener(NotificationMessageListener listener);
    
    /**
     * 
     * @return The listeners that are currently receiving notifications.
     *
     */
    Collection getMessageListeners();
    
    /**
     * 
     * Informs the resource of WS-N notification messages that have been 
     * received. How the messages are processed by the resource is an 
     * implementation detail.
     *
     * @param messages
     *
     */
    void notify(NotificationMessage[] messages);
    
    void removeMessageListener(NotificationMessageListener listener);
}
