/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.notification;

import org.apache.muse.core.Capability;
import org.apache.muse.ws.notification.faults.UnableToGetMessagesFault;
import org.apache.muse.ws.resource.WsResource;

/**
 * 
 * PullPoint is an interface that represents the WS-Notification PullPoint 
 * port type; it is based on WS-N 1.3. This interface adds methods for 
 * discovering information about the types of messages the pullpoint stores 
 * and how it stores them.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public interface PullPoint extends Capability
{
    /**
     * 
     * @return The storage API that is used to store the messages received by 
     *         the pullpoint from a resource.
     *
     */
    PullPointDataStore getDataStore();
    
    /**
     * 
     * @return The filter that is used by the pullpoint resource when it is 
     *         subscribing to notifications on a target resource.
     *
     */
    Filter getFilter();
    
    /**
     * 
     * @see PullPointDataStore#getMessages(int)
     *
     */
    NotificationMessage[] getMessages(int maxNumber)
        throws UnableToGetMessagesFault;
    
    /**
     * 
     * @return The subscription resource that the pullpoint set up to receive 
     *         its messages.
     *
     */
    WsResource getSubscription();
    
    void setSubscription(WsResource sub);
}
