/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.notification.remote;

import org.w3c.dom.Element;

import org.apache.muse.core.Environment;
import org.apache.muse.ws.addressing.EndpointReference;
import org.apache.muse.ws.notification.WsnConstants;
import org.apache.muse.ws.resource.remote.WsResourceClient;
import org.apache.muse.ws.addressing.soap.SoapClient;
import org.apache.muse.ws.addressing.soap.SoapFault;
import org.apache.muse.util.xml.XmlUtils;

/**
 *
 * SubscriptionClient is a web services client for resources that implement the 
 * WS-N SubscriptionManager port type. It adds the pauseSubscription() and 
 * resumeSubscription() methods to the base WS-RF interfaces.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class SubscriptionClient extends WsResourceClient
{
    public SubscriptionClient(EndpointReference destination)
    {
        super(destination);
    }
    
    public SubscriptionClient(EndpointReference destination,
                              EndpointReference source)
    {
        super(destination, source);
    }
    
    public SubscriptionClient(EndpointReference destination,
                              EndpointReference source, 
                              Environment environment)
    {
        super(destination, source, environment);
    }
    
    public SubscriptionClient(EndpointReference destination,
                              EndpointReference source, 
                              SoapClient soapClient)
    {
        super(destination, source, soapClient);
    }
    
    public void pauseSubscription()
        throws SoapFault
    {
        Element body = XmlUtils.createElement(WsnConstants.PAUSE_QNAME);
        invoke(WsnConstants.PAUSE_URI, body);
    }
    
    public void resumeSubscription()
        throws SoapFault
    {
        Element body = XmlUtils.createElement(WsnConstants.RESUME_QNAME);
        invoke(WsnConstants.RESUME_URI, body);
    }
}
