/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.resource;

import org.apache.muse.core.Capability;

/**
 * 
 * WsResourceCapability is an extension of the core Muse Capability concept. 
 * It provides a safely-typed convenience method for accessing the WS-resource 
 * that contains the capability as well as generic, WSRP-like methods for 
 * accessing its property values. A WsResourceCapability is responsible for 
 * its own state - the WSRP ResourcePropertyCollection will use these capabilities 
 * as delegates for reading and writing property values. This allows the 
 * WS-resource capabilities to leverage different state models within a single 
 * resource type.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public interface WsResourceCapability 
    extends Capability, WsResourceCapabilityProperties
{
    /**
     * 
     * @return The same as getResource(), cast to the WsResource type.
     *
     */
    WsResource getWsResource();
}
