/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.resource.properties;

import org.apache.muse.util.xml.XmlSerializable;
import org.apache.muse.ws.resource.metadata.ResourcePropertiesMetadataValidation;
import org.apache.muse.ws.resource.properties.get.GetMultipleResourceProperties;
import org.apache.muse.ws.resource.properties.get.GetResourceProperty;
import org.apache.muse.ws.resource.properties.get.GetResourcePropertyDocument;
import org.apache.muse.ws.resource.properties.get.ext.GetResourcePropertyExtensions;
import org.apache.muse.ws.resource.properties.listeners.ResourcePropertyListeners;
import org.apache.muse.ws.resource.properties.schema.ResourcePropertiesSchemaValidation;
import org.apache.muse.ws.resource.properties.set.PutResourcePropertyDocument;
import org.apache.muse.ws.resource.properties.set.SetResourceProperties;
import org.apache.muse.ws.resource.properties.set.SetResourcePropertiesComponents;
import org.apache.muse.ws.resource.properties.set.SetResourcePropertiesPermissions;
import org.apache.muse.ws.resource.properties.set.ext.SetResourcePropertiesExtensions;

/**
 * 
 * ResourcePropertyCollection is the WSRP-based state model that is used by 
 * all WS-resources. It does not imply or require the use of any WSRP 
 * capabilities for remote clients; users must specify said capabilities 
 * in muse.xml (with the <em>capability</em> tag) if they want to do this.
 * <br><br>
 * The ResourcePropertyCollection provides a single, generic interface for 
 * reading and writing resource properties that are spread across disparate 
 * Capability objects. Read and write requests will be delegated to the 
 * appropriate {@linkplain org.apache.muse.ws.resource.WsResourceCapability capabilities} 
 * after all schema and metadata validation is done. This interface also implies 
 * the use of various listeners, which allow users to hook into the read and 
 * write requests at various points to respond to them with their own code. 
 * The crux of the ResourcePropertyCollection's role, then, is the administrative 
 * and plumbing tasks necessary to read, write, validate, and report on 
 * resource properties, but not the actual storage of the properties themselves.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public interface ResourcePropertyCollection
    extends GetMultipleResourceProperties, 
            GetResourceProperty, 
            GetResourcePropertyExtensions, 
            GetResourcePropertyDocument, 
            PutResourcePropertyDocument, 
            SetResourceProperties, 
            SetResourcePropertiesComponents, 
            SetResourcePropertiesExtensions, 
            SetResourcePropertiesPermissions, 
            ResourcePropertyListeners, 
            ResourcePropertiesMetadataValidation, 
            ResourcePropertiesSchemaValidation, 
            XmlSerializable
{
    //
    // no additional methods - this is an aggregate type
    //
}
