/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.resource.properties.query;

import java.util.Collection;

import org.apache.muse.ws.resource.properties.query.faults.UnknownQueryExpressionDialectFault;

/**
 * 
 * QueryExpressionFactory is a means of generating executable 
 * {@linkplain QueryExpression QueryExpressions} for a set of dialects 
 * without having to reference specific dialects or language constructs 
 * in the calling code.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public interface QueryExpressionFactory
{
    /**
     * 
     * @return The URIs that represent the query dialects supported by this factory.
     *
     */
    Collection getDialects();
    
    /**
     * 
     * @param dialect
     * 
     * @return A QueryExpression object that can be used to evaluate queries 
     *         for the given dialect.
     * 
     * @throws UnknownQueryExpressionDialectFault
     *
     */
    QueryExpression newInstance(String dialect) 
        throws UnknownQueryExpressionDialectFault;
}
