/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.resource.properties.query;

import javax.xml.namespace.QName;

import org.w3c.dom.Node;

import org.apache.muse.ws.resource.basefaults.BaseFault;
import org.apache.muse.ws.resource.properties.WsrpConstants;
import org.apache.muse.ws.resource.properties.query.faults.InvalidQueryExpressionFault;
import org.apache.muse.ws.resource.properties.query.faults.QueryEvaluationErrorFault;
import org.apache.muse.ws.resource.properties.query.faults.UnknownQueryExpressionDialectFault;

/**
 *
 * @author Dan Jemiolo (danj)
 *
 */

public interface QueryResourceProperties
{
    QName[] PROPERTIES = new QName[]{
        WsrpConstants.QUERY_DIALECT_QNAME
    };
    
    String[] getQueryExpressionDialect()
        throws BaseFault;
    
    /**
     * 
     * Returns a set of DOM Nodes that correlates to the given query string. 
     *
     * @param query
     *        The query expression to evaluate against the WS-RP document.
     * 
     * @param dialect
     *        The name of the query language used for the query.
     * 
     * @return The set of DOM Nodes that correlates to the given query string. 
     *         These XML nodes may be entire property instances or just 
     *         fragments of instances (sub-elements, text, etc.). There is no 
     *         guarantee that all of the nodes have a similar structure or 
     *         type. There may be further restrictions on the return value 
     *         depending on which query language(s) is supported by the WS-RP 
     *         implementation.
     * 
     * @throws BaseFault
     *         <ul>
     *         <li>If the dialect (query language) is not supported by the 
     *         implementation.</li>
     *         <li>If the query expression is invalid, or there was an error 
     *         processing the results of the query.</li>
     *         </ul>
     *
     */
    Node[] queryResourceProperties(String query, String dialect)
        throws UnknownQueryExpressionDialectFault, 
               InvalidQueryExpressionFault, 
               QueryEvaluationErrorFault, 
               BaseFault;
}
