/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.resource.properties.set.ext;

import javax.xml.namespace.QName;

import org.apache.muse.ws.resource.basefaults.BaseFault;

/**
 *
 * SetResourcePropertiesExtensions is a collection of non-standard WS-RP 
 * extensions that is needed in order to perform common internal operations. 
 * The WS-RP spec does not provide a way to modify individual instances of 
 * a property; rather, operations like Update and Delete are required to 
 * change <b>all</b> instances of a property. This is an obstacle for many 
 * types of properties.
 * <br><br>
 * The methods in this interface should <b>not</b> be exposed to the outside 
 * world, only to internal callers who have permission to make modifications 
 * that standards-compliant clients would not be allowed to make. 
 *
 * @author Dan Jemiolo (danj)
 *
 */

public interface SetResourcePropertiesExtensions
{
    /**
     * 
     * This is just a convenience method that will call 
     * insertOrUpdate(QName, Object[]) with a one-element array.
     *
     */
    void insertOrUpdate(QName property, Object value)
        throws BaseFault;
    
    /**
     * 
     * Checks to see if there is already an instance of the property, and if 
     * so, updates it with the given values; otherwise, it inserts the values. 
     * The former maps to update(QName, Object[]), the latter to 
     * insert(QName, Object[]). This method should be used when you want to 
     * override a default value for a property that may have already been set.
     * <br><br>
     * This method is <b>not</b> thread-safe in that there is a possibility 
     * that another WS-RP set request will happen in between the time the 
     * read test is done (to determine existence) and the set is done.
     *
     */
    void insertOrUpdate(QName property, Object[] values)
        throws BaseFault;
}
