/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.resource.lifetime.impl;

import java.util.Date;

import org.w3c.dom.Element;

import org.apache.muse.core.routing.AbstractMessageHandler;
import org.apache.muse.ws.addressing.soap.SoapFault;
import org.apache.muse.ws.resource.lifetime.WsrlConstants;

/**
 *
 * SetTerminationTimeHandler is the parser for the WS-ImmediateTermination 
 * SetTerminationTime operation.
 *
 * @author Dan Jemiolo (danj)
 * 
 * @see org.apache.muse.ws.resource.lifetime.ImmediateTermination
 *
 */

public class SetTerminationTimeHandler extends AbstractMessageHandler
{
    public SetTerminationTimeHandler()
    {
        super(WsrlConstants.SET_TERMINATION_URI, WsrlConstants.SET_TERMINATION_QNAME);
    }

    public Object[] fromXML(Element xml)
        throws SoapFault
    {
        SetTerminationTime request = new SetTerminationTime(xml);
        return new Object[]{ request.getTerminationTime() };
    }

    public Element toXML(Object result)
    {
        SetTerminationTimeResponse response = new SetTerminationTimeResponse((Date)result);
        return response.toXML();
    }
}
