/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.resource.metadata.impl;

import javax.xml.namespace.QName;

import org.w3c.dom.Element;

import org.apache.muse.util.messages.Messages;
import org.apache.muse.util.messages.MessagesFactory;
import org.apache.muse.ws.resource.basefaults.BaseFault;
import org.apache.muse.ws.resource.properties.listeners.AbstractChangeApprover;
import org.apache.muse.ws.resource.properties.listeners.PropertyChangeApprover;
import org.apache.muse.ws.resource.properties.set.faults.UnableToModifyResourcePropertyFault;

/**
 *
 * InsertOnlyApprover is a 
 * {@linkplain PropertyChangeApprover PropertyChangeApprover} that throws an 
 * exception if a request tries to perform a WS-RP Delete or Update on a 
 * property. In this case, the property is not immutable (since we can insert 
 * new instances of it), but the property <em>instances</em> are.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class InsertOnlyApprover extends AbstractChangeApprover
{
    //
    // Used to lookup all exception messages
    //
    private static Messages _MESSAGES = MessagesFactory.get(InsertOnlyApprover.class);
    
    public InsertOnlyApprover(QName qname)
    {
        super(qname);
    }
    
    /**
     * 
     * Throws an exception if the first parameter is not null (signifying 
     * an update or deletion of an existing property).
     *
     */
    public void validateChange(Element oldValue, Element newValue, Object token) 
        throws BaseFault
    {
        //
        // if an old value exists, it means we're updating that old value 
        // or deleting it - BAD
        //
        if (oldValue != null)
        {
            Object[] filler = { getPropertyName() };
            throw new UnableToModifyResourcePropertyFault(_MESSAGES.get("InsertOnly", filler));
        }
    }
}
