/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.resource.properties.get.impl;

import javax.xml.namespace.QName;

import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;

import org.apache.muse.util.messages.Messages;
import org.apache.muse.util.messages.MessagesFactory;
import org.apache.muse.ws.resource.properties.WsrpConstants;
import org.apache.muse.util.xml.XmlSerializable;
import org.apache.muse.util.xml.XmlUtils;

/**
 *
 * GetMultipleResponse is a serializer/deserializer for the WS-ResourceProperties 
 * GetMultipleResourceProperties operation's response content.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class GetMultipleResponse implements XmlSerializable
{
    //
    // Used to lookup all exception messages
    //
    private static Messages _MESSAGES = MessagesFactory.get(GetMultipleResponse.class);
    
    //
    // The property instances retrieved for a GetMultipleResourceProperties 
    // request. This may be empty.
    //
    private Element[] _properties = null;
    
    public GetMultipleResponse(Element[] properties)
    {
        if (properties == null)
            throw new NullPointerException(_MESSAGES.get("NullElementArray"));
        
        for (int n = 0; n < properties.length; ++n)
        {
            if (properties[n] == null)
            {
                Object[] filler = { new Integer(n) };
                throw new NullPointerException(_MESSAGES.get("NullInstanceN", filler));
            }
        }
        
        _properties = properties;
    }
    
    public int getNumberOfProperties()
    {
        return _properties.length;
    }

    public Element[] getProperties()
    {
        return _properties;
    }

    public Element getProperty(int index)
    {
        return _properties[index];
    }
    
    public QName getPropertyName(int index)
    {
        return XmlUtils.getElementQName(getProperty(index));
    }

    public boolean isEmpty()
    {
        return _properties.length == 0;
    }
    
    public String toString()
    {
        return XmlUtils.toString(toXML(), false);
    }
    
    public Element toXML()
    {
        return toXML(XmlUtils.EMPTY_DOC);
    }
    
    public Element toXML(Document doc)
    {
        QName qname = WsrpConstants.GET_MULTIPLE_RESPONSE_QNAME;
        Element root = XmlUtils.createElement(doc, qname);
        
        for (int n = 0; n < _properties.length; ++n)
        {
            Node property = doc.importNode(_properties[n], true);
            root.appendChild(property);
        }
        
        return root;
    }
}
