/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.metadata.impl;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import org.apache.muse.util.xml.XmlSerializable;
import org.apache.muse.util.xml.XmlUtils;
import org.apache.muse.ws.metadata.WsxConstants;

/**
 *
 * GetMetadataRequest is a serializer/deserializer for the WS-MetadataExchange 
 * GetMetadata operation's request content.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class GetMetadataRequest implements XmlSerializable
{
    //
    // The type of metadata to retrieve
    //
    private String _dialect = null;
    
    public GetMetadataRequest(Element request)
    {
        _dialect = XmlUtils.getElementText(request, WsxConstants.DIALECT_QNAME);
    }
    
    public GetMetadataRequest(String dialect)
    {
        _dialect = dialect;
    }
    
    public String getDialect()
    {
        return _dialect;
    }
    
    public Element toXML()
    {
        return toXML(XmlUtils.EMPTY_DOC);
    }
    
    public Element toXML(Document doc)
    {
        Element dialect = XmlUtils.createElement(doc, WsxConstants.DIALECT_QNAME, getDialect());
        return XmlUtils.createElement(doc, WsxConstants.GET_METADATA_QNAME, dialect, false);
    }
}
