/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.osgi.ws.dm.muws.adv.impl;

import org.apache.muse.util.osgi.AbstractResourceManagementImplementation;
import org.apache.muse.util.osgi.CapabilityPair;
import org.osgi.framework.Bundle;
import org.osgi.framework.ServiceFactory;
import org.osgi.framework.ServiceRegistration;

/**
 * MUWSADVImplementationService is an implementation of the <code>ResourceManagementImplementation</code>
 * service interface for the MUWS Advertisement Implementation bundle.
 * 
 * @see ResourceManagementImplementation
 * @author Joel Hawkins (joelh)
 *
 */
public class MUWSADVImplementationService extends AbstractResourceManagementImplementation implements ServiceFactory {
	private static final String IMPLEMENTATION_NAME = "muws_adv_impl";
	
	private static final String[] capabilityURI = {
		"http://docs.oasis-open.org/wsdm/muws/capabilities/Advertisement",
		"http://docs.oasis-open.org/wsdm/muws/capabilities/Advertisement",
		"http://docs.oasis-open.org/wsdm/muws/capabilities/Advertisement"
	};
	
	private static final String[] capabilityImplementation = {
		"org.apache.muse.ws.dm.muws.adv.impl.SimpleAdvertisement",
		"org.apache.muse.ws.dm.muws.adv.impl.ServiceGroupEntryAdvertisement",
		"org.apache.muse.ws.dm.muws.adv.impl.BroadcastAdvertisement"
	};
	
	private static CapabilityPair[] capabilityCollection = {
		new CapabilityPair(capabilityURI[0],capabilityImplementation[0]),
		new CapabilityPair(capabilityURI[1],capabilityImplementation[1]),
		new CapabilityPair(capabilityURI[2],capabilityImplementation[2])
	};
	
	public MUWSADVImplementationService(Bundle bundle){
		super(bundle);
		this.implementationName = IMPLEMENTATION_NAME;
		this.capabilityMappings = capabilityCollection;
	}

	public Object getService(Bundle bundle, ServiceRegistration registration) {
		return this;
	}

	public void ungetService(Bundle bundle, ServiceRegistration registration, Object service) {
	}
}
