/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/
package org.apache.muse.osgi.wsx.impl;

import org.apache.muse.util.osgi.AbstractResourceManagementImplementation;
import org.apache.muse.util.osgi.CapabilityPair;
import org.osgi.framework.Bundle;
import org.osgi.framework.ServiceFactory;
import org.osgi.framework.ServiceRegistration;

/**
 * WSXImplementationService is an implementation of the <code>ResourceManagementImplementation</code>
 * service interface for the WS-MetaData Exchange Implementation bundle.
 * 
 * @see ResourceManagementImplementation
 * @author Joel Hawkins (joelh)
 *
 */
public class WSXImplementationService extends AbstractResourceManagementImplementation implements ServiceFactory {
	private static final String IMPLEMENTATION_NAME = "wsx_impl";

	private static final String[] capabilityURI = {
		"http://schemas.xmlsoap.org/ws/2004/09/mex/GetMetadata"
	};
	
	private static final String[] capabilityImplementation = {
		"org.apache.muse.ws.metadata.impl.SimpleMetadataExchange"
	};
	
	private CapabilityPair capabilities[] = {
		new CapabilityPair(capabilityURI[0],capabilityImplementation[0])	
	};
	
	public WSXImplementationService(Bundle bundle){
		super(bundle);
		this.implementationName = IMPLEMENTATION_NAME;
		this.capabilityMappings = capabilities;
	}

	public Object getService(Bundle bundle, ServiceRegistration registration) {
		return this;
	}

	public void ungetService(Bundle bundle, ServiceRegistration registration, Object service) {
	}
}
